import i18n_config from 's-i18n.config';
import translations from 'i18n/';
import { Translator } from '../Translator';

const t = new Translator(i18n_config, translations);

t.setLanguage('fr');
const _ = t.t.bind(t);

test('Supports basic translation', () => {
  expect(_('Extract me')).toEqual('Extrais moi');
});

test('Supports translation with a placeholder', () => {
  expect(_('hello {user}', { user: 'Mehdi' })).toEqual('bonjour Mehdi');
});

it('Supports no placeholders', () => {
  const received = _('simple sentence');
  expect(received).toEqual('simple sentence');
});

it('Supports placeholder at start', () => {
  const received = _('{placeholder} at start', {
    placeholder: 'foo'
  });
  expect(received).toEqual('foo at start');
});

it('Supports placeholder at middle', () => {
  const received = _('Placeholder {at} middle', {
    at: '@'
  });
  expect(received).toEqual('Placeholder @ middle');
});

it('Supports placeholder in the end', () => {
  const received = _('Placeholder in the {end}', {
    end: 'bar'
  });
  expect(received).toEqual('Placeholder in the bar');
});

it('Supports emoji as placeholder', () => {
  const received = _('This uses a {💩} as a placeholder', {
    '💩': 'pile of poo'
  });
  expect(received).toEqual('This uses a pile of poo as a placeholder');
});

it('Supports two consecutives placeholders!', () => {
  const received = _('Two {consecutive} {placeholders}!', {
    consecutive: 'foo',
    placeholders: 'bar'
  });
  expect(received).toEqual('Two foo bar!');
});

it('Supports a placeholder used twice', () => {
  const received = _('Same {placeholder} {placeholder}', {
    placeholder: 'bar'
  });
  expect(received).toEqual('Same bar bar');
});

it('Supports plurals placeholders', () => {
  expect(
    _('There {n,plural,=0{are no dogs} =1{is one dog} =*{are # dogs}}!', {
      n: 0
    })
  ).toEqual('There are no dogs!');
  expect(
    _('There {n,plural,=0{are no dogs} =1{is one dog} =*{are # dogs}}!', {
      n: 1
    })
  ).toEqual('There is one dog!');
  expect(
    _('There {n,plural,=0{are no dogs} =1{is one dog} =*{are # dogs}}!', {
      n: 42
    })
  ).toEqual('There are 42 dogs!');
});

it('Supports numerical placeholders', () => {
  const received = _('This {0} is {1}', ['foo', 'bar']);
  expect(received).toEqual('This foo is bar');
  expect(_('This {1} is {0}', ['foo', 'bar'])).toEqual('This bar is foo');
});

it('Supports reversed numerical placeholders', () => {
  const received = _('This {1} is {0}', ['foo', 'bar']);
  expect(received).toEqual('This bar is foo');
});

it('Supports one numerical placeholder as a string', () => {
  const received = _('This will {0} well!', 'work');
  expect(received).toEqual('This will work well!');
});

it('Warns about missing placeholder', () => {
  const received = _('Warn about {missing} placeholder');
  expect(received).toEqual('Warn about ⚠️ placeholder');
});
